@@ -6,7 +6,7 @@ INSTALLED_APPS = [
     'haystack',
     'djcelery',
     'celery_haystack',
-    'notes',
+    'tests',
 ]
 
 DATABASES = {
@@ -16,11 +16,12 @@ DATABASES = {
     }
 }
 
-HAYSTACK_SITECONF = 'notes.search_sites'
+HAYSTACK_SITECONF = 'tests.search_sites'
 HAYSTACK_SEARCH_ENGINE = 'whoosh'
 HAYSTACK_WHOOSH_PATH = path.join(TEST_ROOT, 'whoosh_index')
 
 BROKER_TRANSPORT = "memory"
+CELERY_ALWAYS_EAGER = True
 CELERY_IGNORE_RESULT = True
 CELERYD_LOG_LEVEL = "DEBUG"
 CELERY_DEFAULT_QUEUE = "celery-haystack"
